AI-Chatter Documentation
========================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. relativeinclude:: ../README.md
   :parser: myst_parser.docutils_

.. templates etc. courtesy of `James A. Leedham <https://github.com/JamesALeedham/Sphinx-Autosummary-Recursion/>`

.. autosummary::
   :toctree: generated
   :template: module.rst
   :recursive:

   ai_chatter.db
   ai_chatter.enums
   ai_chatter.communication
   ai_chatter.apps
   ai_chatter.utils
